@@ -87,7 +87,7 @@ print_common_flags(struct tcb *tcp, const struct iocb *cb)
 		printfd(tcp, cb->aio_resfd);
 	}
 	if (cb->aio_flags & ~IOCB_FLAG_RESFD)
-		tprintf(", flags=%x", cb->aio_flags);
+		tprintf(", flags=%#x", cb->aio_flags);
 #endif
 }
 
@@ -130,8 +130,7 @@ print_iocb(struct tcb *tcp, const struct iocb *cb)
 	case SUB_COMMON:
 		if (cb->aio_lio_opcode == 1 && iocb_is_valid(cb)) {
 			tprints(", str=");
-			printstr(tcp, (unsigned long) cb->aio_buf,
-				 (unsigned long) cb->aio_nbytes);
+			printstrn(tcp, cb->aio_buf, cb->aio_nbytes);
 		} else {
 			tprintf(", buf=%#" PRIx64, (uint64_t) cb->aio_buf);
 		}
@@ -162,13 +161,13 @@ print_iocb(struct tcb *tcp, const struct iocb *cb)
 static bool
 print_iocbp(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 {
-	unsigned long addr;
+	kernel_ulong_t addr;
 	struct iocb cb;
 
-	if (elem_size < sizeof(long)) {
+	if (elem_size < sizeof(kernel_ulong_t)) {
 		addr = * (unsigned int *) elem_buf;
 	} else {
-		addr = * (unsigned long *) elem_buf;
+		addr = * (kernel_ulong_t *) elem_buf;
 	}
 
 	tprints("{");
@@ -181,12 +180,13 @@ print_iocbp(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 
 SYS_FUNC(io_submit)
 {
-	const long nr = widen_to_long(tcp->u_arg[1]);
-	const unsigned long addr = tcp->u_arg[2];
-	unsigned long iocbp;
+	const kernel_long_t nr =
+		truncate_klong_to_current_wordsize(tcp->u_arg[1]);
+	const kernel_ulong_t addr = tcp->u_arg[2];
+	kernel_ulong_t iocbp;
 
 	printaddr(tcp->u_arg[0]);
-	tprintf(", %ld, ", nr);
+	tprintf(", %" PRI_kld ", ", nr);
 
 	if (nr < 0)
 		printaddr(addr);
@@ -237,9 +237,9 @@ SYS_FUNC(io_getevents)
 {
 	if (entering(tcp)) {
 		printaddr(tcp->u_arg[0]);
-		tprintf(", %ld, %ld, ",
-			widen_to_long(tcp->u_arg[1]),
-			widen_to_long(tcp->u_arg[2]));
+		tprintf(", %" PRI_kld ", %" PRI_kld ", ",
+			truncate_klong_to_current_wordsize(tcp->u_arg[1]),
+			truncate_klong_to_current_wordsize(tcp->u_arg[2]));
 	} else {
 		struct io_event buf;
 		print_array(tcp, tcp->u_arg[3], tcp->u_rval, &buf, sizeof(buf),
