@@ -51,10 +51,11 @@
 #include <errno.h>
 #include <time.h>
 #include <sys/time.h>
-#include <asm/unistd.h>
 
+#include "kernel_types.h"
 #include "mpers_type.h"
 #include "gcc_compat.h"
+#include "sysent.h"
 
 #ifndef HAVE_STRERROR
 const char *strerror(int);
@@ -124,15 +125,6 @@ extern char *stpcpy(char *dst, const char *src);
 #define USE_SEIZE 1
 /* To force NOMMU build, set to 1 */
 #define NOMMU_SYSTEM 0
-/*
- * Set to 1 to use speed-optimized vfprintf implementation.
- * It results in strace using about 5% less CPU in user space
- * (compared to glibc version).
- * But strace spends a lot of time in kernel space,
- * so overall it does not appear to be a significant win.
- * Thus disabled by default.
- */
-#define USE_CUSTOM_PRINTF 0
 
 #ifndef ERESTARTSYS
 # define ERESTARTSYS    512
@@ -149,7 +141,8 @@ extern char *stpcpy(char *dst, const char *src);
 
 #if defined X86_64
 # define SUPPORTED_PERSONALITIES 3
-# define PERSONALITY2_WORDSIZE 4
+# define PERSONALITY2_WORDSIZE  4
+# define PERSONALITY2_KLONGSIZE PERSONALITY0_KLONGSIZE
 #elif defined AARCH64 \
    || defined POWERPC64 \
    || defined RISCV \
@@ -167,12 +160,14 @@ extern char *stpcpy(char *dst, const char *src);
 # define DEFAULT_PERSONALITY 0
 #endif
 
-#define PERSONALITY0_WORDSIZE SIZEOF_LONG
+#define PERSONALITY0_WORDSIZE  SIZEOF_LONG
+#define PERSONALITY0_KLONGSIZE SIZEOF_KERNEL_LONG_T
 #define PERSONALITY0_INCLUDE_PRINTERS_DECLS "native_printer_decls.h"
 #define PERSONALITY0_INCLUDE_PRINTERS_DEFS "native_printer_defs.h"
 
 #if SUPPORTED_PERSONALITIES > 1
-# define PERSONALITY1_WORDSIZE 4
+# define PERSONALITY1_WORDSIZE  4
+# define PERSONALITY1_KLONGSIZE PERSONALITY1_WORDSIZE
 #endif
 
 #if SUPPORTED_PERSONALITIES > 1 && defined HAVE_M32_MPERS
@@ -197,30 +192,20 @@ extern char *stpcpy(char *dst, const char *src);
 # define PERSONALITY2_INCLUDE_FUNCS "empty.h"
 #endif
 
-typedef struct sysent {
-	unsigned nargs;
-	int	sys_flags;
-	int	sen;
-	int	(*sys_func)();
-	const char *sys_name;
-} struct_sysent;
-
 typedef struct ioctlent {
 	const char *symbol;
 	unsigned int code;
 } struct_ioctlent;
 
-struct fault_opts {
+struct inject_opts {
 	uint16_t first;
 	uint16_t step;
-	uint16_t err;
+	uint16_t signo;
+	int rval;
 };
 
-#if defined LINUX_MIPSN32 || defined X32
-# define HAVE_STRUCT_TCB_EXT_ARG 1
-#else
-# define HAVE_STRUCT_TCB_EXT_ARG 0
-#endif
+#define MAX_ERRNO_VALUE			4095
+#define INJECT_OPTS_RVAL_DEFAULT	(-(MAX_ERRNO_VALUE + 1))
 
 /* Trace Control Block */
 struct tcb {
@@ -228,13 +213,9 @@ struct tcb {
 	int pid;		/* If 0, this tcb is free */
 	int qual_flg;		/* qual_flags[scno] or DEFAULT_QUAL_FLAGS + RAW */
 	unsigned long u_error;	/* Error code */
-	long scno;		/* System call number */
-	long u_arg[MAX_ARGS];	/* System call arguments */
-#if HAVE_STRUCT_TCB_EXT_ARG
-	long long ext_arg[MAX_ARGS];
-	long long u_lrval;	/* long long return value */
-#endif
-	long u_rval;		/* Return value */
+	kernel_ulong_t scno;	/* System call number */
+	kernel_ulong_t u_arg[MAX_ARGS];	/* System call arguments */
+	kernel_long_t u_rval;	/* Return value */
 #if SUPPORTED_PERSONALITIES > 1
 	unsigned int currpers;	/* Personality at the time of scno update */
 #endif
@@ -246,7 +227,7 @@ struct tcb {
 	void (*_free_priv_data)(void *); /* Callback for freeing priv_data */
 	const struct_sysent *s_ent; /* sysent[scno] or dummy struct for bad scno */
 	const struct_sysent *s_prev_ent; /* for "resuming interrupted SYSCALL" msg */
-	struct fault_opts *fault_vec[SUPPORTED_PERSONALITIES];
+	struct inject_opts *inject_vec[SUPPORTED_PERSONALITIES];
 	struct timeval stime;	/* System time usage as of last process wait */
 	struct timeval dtime;	/* Delta for system time usage */
 	struct timeval etime;	/* Syscall entry time */
@@ -283,7 +264,7 @@ struct tcb {
 #define TCB_ATTACHED	0x08	/* We attached to it already */
 #define TCB_REPRINT	0x10	/* We should reprint this syscall on exit */
 #define TCB_FILTERED	0x20	/* This system call has been filtered out */
-#define TCB_FAULT_INJ	0x40	/* A syscall fault has been injected */
+#define TCB_TAMPERED	0x40	/* A syscall has been tampered with */
 #define TCB_HIDE_LOG	0x80	/* We should hide everything (until execve) */
 #define TCB_SKIP_DETACH_ON_FIRST_EXEC	0x100	/* -b execve should skip detach on first execve */
 
@@ -292,7 +273,7 @@ struct tcb {
 #define QUAL_ABBREV	0x002	/* abbreviate the structures of this syscall */
 #define QUAL_VERBOSE	0x004	/* decode the structures of this syscall */
 #define QUAL_RAW	0x008	/* print all args in hex for this syscall */
-#define QUAL_FAULT	0x010	/* fail this system call on purpose */
+#define QUAL_INJECT	0x010	/* tamper with this system call on purpose */
 #define QUAL_SIGNAL	0x100	/* report events with this signal */
 #define QUAL_READ	0x200	/* dump data read from this file descriptor */
 #define QUAL_WRITE	0x400	/* dump data written to this file descriptor */
@@ -317,6 +298,7 @@ extern const struct xlat msg_flags[];
 extern const struct xlat open_access_modes[];
 extern const struct xlat open_mode_flags[];
 extern const struct xlat resource_flags[];
+extern const struct xlat sg_io_info[];
 extern const struct xlat socketlayers[];
 extern const struct xlat whence_codes[];
 
@@ -325,34 +307,14 @@ extern const struct xlat whence_codes[];
 #define RVAL_HEX	001	/* hex format */
 #define RVAL_OCTAL	002	/* octal format */
 #define RVAL_UDECIMAL	003	/* unsigned decimal format */
-#if HAVE_STRUCT_TCB_EXT_ARG
-# if 0 /* unused so far */
-#  define RVAL_LDECIMAL	004	/* long decimal format */
-#  define RVAL_LHEX	005	/* long hex format */
-#  define RVAL_LOCTAL	006	/* long octal format */
-# endif
-# define RVAL_LUDECIMAL	007	/* long unsigned decimal format */
-#endif /* HAVE_STRUCT_TCB_EXT_ARG */
 #define RVAL_FD		010	/* file descriptor */
-#define RVAL_MASK	017	/* mask for these values */
+#define RVAL_MASK	013	/* mask for these values */
 
 #define RVAL_STR	020	/* Print `auxstr' field after return val */
 #define RVAL_NONE	040	/* Print nothing */
 
 #define RVAL_DECODED	0100	/* syscall decoding finished */
 
-#define TRACE_FILE	001	/* Trace file-related syscalls. */
-#define TRACE_IPC	002	/* Trace IPC-related syscalls. */
-#define TRACE_NETWORK	004	/* Trace network-related syscalls. */
-#define TRACE_PROCESS	010	/* Trace process-related syscalls. */
-#define TRACE_SIGNAL	020	/* Trace signal-related syscalls. */
-#define TRACE_DESC	040	/* Trace file descriptor-related syscalls. */
-#define TRACE_MEMORY	0100	/* Trace memory mapping-related syscalls. */
-#define SYSCALL_NEVER_FAILS	0200	/* Syscall is always successful. */
-#define STACKTRACE_INVALIDATE_CACHE 0400  /* Trigger proc/maps cache updating */
-#define STACKTRACE_CAPTURE_ON_ENTER 01000 /* Capture stacktrace on "entering" stage */
-#define TRACE_INDIRECT_SUBCALL	02000	/* Syscall is an indirect socket/ipc subcall. */
-
 #define IOCTL_NUMBER_UNKNOWN 0
 #define IOCTL_NUMBER_HANDLED 1
 #define IOCTL_NUMBER_STOP_LOOKUP 010
@@ -437,22 +399,12 @@ void *xreallocarray(void *ptr, size_t nmemb, size_t size)
 	ATTRIBUTE_ALLOC_SIZE((2, 3));
 char *xstrdup(const char *str) ATTRIBUTE_MALLOC;
 
-#if USE_CUSTOM_PRINTF
-/*
- * See comment in vsprintf.c for allowed formats.
- * Short version: %h[h]u, %zu, %tu are not allowed, use %[l[l]]u.
- */
-int strace_vfprintf(FILE *fp, const char *fmt, va_list args);
-#else
-# define strace_vfprintf vfprintf
-#endif
-
 extern int read_int_from_file(const char *, int *);
 
 extern void set_sortby(const char *);
 extern void set_overhead(int);
 extern void print_pc(struct tcb *);
-extern int trace_syscall(struct tcb *);
+extern int trace_syscall(struct tcb *, unsigned int *);
 extern void count_syscall(struct tcb *, const struct timeval *);
 extern void call_summary(FILE *);
 
@@ -466,7 +418,7 @@ extern int get_scno(struct tcb *tcp);
  * @return     String literal corresponding to the syscall number in case latter
  *             is valid; NULL otherwise.
  */
-extern const char *syscall_name(long scno);
+extern const char *syscall_name(kernel_ulong_t scno);
 extern const char *err_name(unsigned long err);
 
 extern bool is_erestart(struct tcb *);
@@ -488,34 +440,42 @@ static inline int set_tcb_priv_ulong(struct tcb *tcp, unsigned long val)
 	return set_tcb_priv_data(tcp, (void *) val, 0);
 }
 
-extern int umoven(struct tcb *, long, unsigned int, void *);
+extern int
+umoven(struct tcb *tcp, kernel_ulong_t addr, unsigned int len, void *laddr);
 #define umove(pid, addr, objp)	\
 	umoven((pid), (addr), sizeof(*(objp)), (void *) (objp))
-extern int umoven_or_printaddr(struct tcb *, long, unsigned int, void *);
+
+extern int
+umoven_or_printaddr(struct tcb *tcp, kernel_ulong_t addr,
+		    unsigned int len, void *laddr);
 #define umove_or_printaddr(pid, addr, objp)	\
 	umoven_or_printaddr((pid), (addr), sizeof(*(objp)), (void *) (objp))
+
 extern int
-umoven_or_printaddr_ignore_syserror(struct tcb *tcp, const long addr,
-				    const unsigned int len, void *our_addr);
-extern int umovestr(struct tcb *, long, unsigned int, char *);
-extern int upeek(int pid, long, long *);
-extern int upoke(int pid, long, long);
+umoven_or_printaddr_ignore_syserror(struct tcb *tcp, kernel_ulong_t addr,
+				    unsigned int len, void *laddr);
+
+extern int
+umovestr(struct tcb *tcp, kernel_ulong_t addr, unsigned int len, char *laddr);
+
+extern int upeek(int pid, unsigned long, kernel_ulong_t *);
+extern int upoke(int pid, unsigned long, kernel_ulong_t);
 
 extern bool
 print_array(struct tcb *tcp,
-	    const unsigned long start_addr,
-	    const size_t nmemb,
-	    void *const elem_buf,
-	    const size_t elem_size,
-	    int (*const umoven_func)(struct tcb *,
-				     long,
+	    kernel_ulong_t start_addr,
+	    size_t nmemb,
+	    void *elem_buf,
+	    size_t elem_size,
+	    int (*umoven_func)(struct tcb *,
+				     kernel_ulong_t,
 				     unsigned int,
 				     void *),
-	    bool (*const print_func)(struct tcb *,
+	    bool (*print_func)(struct tcb *,
 				     void *elem_buf,
 				     size_t elem_size,
 				     void *opaque_data),
-	    void *const opaque_data);
+	    void *opaque_data);
 
 #if defined ALPHA || defined IA64 || defined MIPS \
  || defined SH || defined SPARC || defined SPARC64
@@ -549,6 +509,7 @@ extern int next_set_bit(const void *bit_array, unsigned cur_bit, unsigned size_b
 #define QUOTE_0_TERMINATED                      0x01
 #define QUOTE_OMIT_LEADING_TRAILING_QUOTES      0x02
 #define QUOTE_OMIT_TRAILING_0                   0x08
+#define QUOTE_FORCE_HEX                         0x10
 
 extern int string_quote(const char *, char *, unsigned int, unsigned int);
 extern int print_quoted_string(const char *, unsigned int, unsigned int);
@@ -557,25 +518,23 @@ extern int print_quoted_string(const char *, unsigned int, unsigned int);
  * b refers to the higher numbered u_arg
  */
 #ifdef WORDS_BIGENDIAN
-# define LONG_LONG(a,b) \
-	((long long)((unsigned long long)(unsigned)(b) | ((unsigned long long)(a)<<32)))
+# define ULONG_LONG(a,b) \
+	((unsigned long long)(unsigned)(b) | ((unsigned long long)(a)<<32))
 #else
-# define LONG_LONG(a,b) \
-	((long long)((unsigned long long)(unsigned)(a) | ((unsigned long long)(b)<<32)))
+# define ULONG_LONG(a,b) \
+	((unsigned long long)(unsigned)(a) | ((unsigned long long)(b)<<32))
 #endif
 extern int getllval(struct tcb *, unsigned long long *, int);
 extern int printllval(struct tcb *, const char *, int)
 	ATTRIBUTE_FORMAT((printf, 2, 0));
 
-extern void printaddr_ull(unsigned long long);
+extern void printaddr(kernel_ulong_t addr);
 extern int printxvals(const uint64_t, const char *, const struct xlat *, ...)
 	ATTRIBUTE_SENTINEL;
 extern int printxval_searchn(const struct xlat *xlat, size_t xlat_size,
 	uint64_t val, const char *dflt);
 #define printxval_search(xlat__, val__, dflt__) \
 	printxval_searchn(xlat__, ARRAY_SIZE(xlat__), val__, dflt__)
-extern long long getarg_ll(struct tcb *tcp, int argn);
-extern unsigned long long getarg_ull(struct tcb *tcp, int argn);
 extern int printargs(struct tcb *);
 extern int printargs_u(struct tcb *);
 extern int printargs_d(struct tcb *);
@@ -587,53 +546,30 @@ extern const char *sprinttime(time_t);
 extern void print_symbolic_mode_t(unsigned int);
 extern void print_numeric_umode_t(unsigned short);
 extern void print_numeric_long_umask(unsigned long);
-extern void dumpiov_in_msghdr(struct tcb *, long, unsigned long);
-extern void dumpiov_in_mmsghdr(struct tcb *, long);
-extern void dumpiov_upto(struct tcb *, int, long, unsigned long);
-#define dumpiov(tcp, len, addr) \
-	dumpiov_upto((tcp), (len), (addr), (unsigned long) -1L)
-extern void dumpstr(struct tcb *, long, int);
-extern void printstr_ex(struct tcb *, long addr, long len,
-	unsigned int user_style);
-extern bool printnum_short(struct tcb *, long, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0));
-extern bool printnum_int(struct tcb *, long, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0));
-extern bool printnum_int64(struct tcb *, long, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0));
+extern void print_dev_t(unsigned long long dev);
 
-#if SUPPORTED_PERSONALITIES > 1 && SIZEOF_LONG > 4
-extern bool printnum_long_int(struct tcb *, long, const char *, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0))
-	ATTRIBUTE_FORMAT((printf, 4, 0));
-# define printnum_slong(tcp, addr) \
-	printnum_long_int((tcp), (addr), "%" PRId64, "%d")
-# define printnum_ulong(tcp, addr) \
-	printnum_long_int((tcp), (addr), "%" PRIu64, "%u")
-# define printnum_ptr(tcp, addr) \
-	printnum_long_int((tcp), (addr), "%#" PRIx64, "%#x")
-#elif SIZEOF_LONG > 4
-# define printnum_slong(tcp, addr) \
-	printnum_int64((tcp), (addr), "%" PRId64)
-# define printnum_ulong(tcp, addr) \
-	printnum_int64((tcp), (addr), "%" PRIu64)
-# define printnum_ptr(tcp, addr) \
-	printnum_int64((tcp), (addr), "%#" PRIx64)
-#else
-# define printnum_slong(tcp, addr) \
-	printnum_int((tcp), (addr), "%d")
-# define printnum_ulong(tcp, addr) \
-	printnum_int((tcp), (addr), "%u")
-# define printnum_ptr(tcp, addr) \
-	printnum_int((tcp), (addr), "%#x")
-#endif
+extern void
+dumpiov_in_msghdr(struct tcb *, kernel_ulong_t addr, kernel_ulong_t data_size);
+
+extern void
+dumpiov_in_mmsghdr(struct tcb *, kernel_ulong_t addr);
+
+extern void
+dumpiov_upto(struct tcb *, int len, kernel_ulong_t addr, kernel_ulong_t data_size);
+
+extern void
+dumpstr(struct tcb *, kernel_ulong_t addr, int len);
+
+extern void
+printstr_ex(struct tcb *, kernel_ulong_t addr, kernel_ulong_t len,
+	    unsigned int user_style);
+
+extern void
+printpathn(struct tcb *, kernel_ulong_t addr, unsigned int n);
+
+extern void
+printpath(struct tcb *, kernel_ulong_t addr);
 
-extern bool printpair_int(struct tcb *, long, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0));
-extern bool printpair_int64(struct tcb *, long, const char *)
-	ATTRIBUTE_FORMAT((printf, 3, 0));
-extern void printpath(struct tcb *, long);
-extern void printpathn(struct tcb *, long, unsigned int);
 #define TIMESPEC_TEXT_BUFSIZE \
 		(sizeof(intmax_t)*3 * 2 + sizeof("{tv_sec=%jd, tv_nsec=%jd}"))
 extern void printfd(struct tcb *, int);
@@ -641,28 +577,46 @@ extern void print_sockaddr(struct tcb *tcp, const void *, int);
 extern bool print_sockaddr_by_inode(const unsigned long, const enum sock_proto);
 extern bool print_sockaddr_by_inode_cached(const unsigned long);
 extern void print_dirfd(struct tcb *, int);
-extern int decode_sockaddr(struct tcb *, long, int);
+
+extern int
+decode_sockaddr(struct tcb *, kernel_ulong_t addr, int addrlen);
+
 extern void printuid(const char *, const unsigned int);
-extern void print_sigset_addr_len(struct tcb *, long, long);
+
+extern void
+print_sigset_addr_len(struct tcb *, kernel_ulong_t addr, kernel_ulong_t len);
+
 extern const char *sprintsigmask_n(const char *, const void *, unsigned int);
 #define tprintsigmask_addr(prefix, mask) \
 	tprints(sprintsigmask_n((prefix), (mask), sizeof(mask)))
 extern void printsignal(int);
-extern void tprint_iov(struct tcb *, unsigned long, unsigned long, enum iov_decode);
-extern void tprint_iov_upto(struct tcb *, unsigned long, unsigned long,
-			    enum iov_decode, unsigned long);
-extern void decode_netlink(struct tcb *, unsigned long, unsigned long);
+
+extern void
+tprint_iov_upto(struct tcb *, kernel_ulong_t len, kernel_ulong_t addr,
+		enum iov_decode, kernel_ulong_t data_size);
+
+extern void
+decode_netlink(struct tcb *, kernel_ulong_t addr, kernel_ulong_t len);
+
 extern void tprint_open_modes(unsigned int);
 extern const char *sprint_open_modes(unsigned int);
-extern void print_seccomp_filter(struct tcb *, unsigned long);
-extern void print_seccomp_fprog(struct tcb *, unsigned long, unsigned short);
+
+extern void
+print_seccomp_filter(struct tcb *, kernel_ulong_t addr);
+
+extern void
+print_seccomp_fprog(struct tcb *, kernel_ulong_t addr, unsigned short len);
 
 struct strace_stat;
 extern void print_struct_stat(struct tcb *tcp, const struct strace_stat *const st);
 
 struct strace_statfs;
-extern void print_struct_statfs(struct tcb *tcp, long);
-extern void print_struct_statfs64(struct tcb *tcp, long, unsigned long);
+
+extern void
+print_struct_statfs(struct tcb *, kernel_ulong_t addr);
+
+extern void
+print_struct_statfs64(struct tcb *, kernel_ulong_t addr, kernel_ulong_t size);
 
 extern void print_ifindex(unsigned int);
 
@@ -675,16 +629,20 @@ extern bool is_number_in_set(unsigned int number, const struct number_set *);
 extern void qualify(const char *);
 extern unsigned int qual_flags(const unsigned int);
 
-extern int dm_ioctl(struct tcb *, const unsigned int, long);
-extern int file_ioctl(struct tcb *, const unsigned int, long);
-extern int fs_x_ioctl(struct tcb *, const unsigned int, long);
-extern int loop_ioctl(struct tcb *, const unsigned int, long);
-extern int ptp_ioctl(struct tcb *, const unsigned int, long);
-extern int scsi_ioctl(struct tcb *, const unsigned int, long);
-extern int sock_ioctl(struct tcb *, const unsigned int, long);
-extern int term_ioctl(struct tcb *, const unsigned int, long);
-extern int ubi_ioctl(struct tcb *, const unsigned int, long);
-extern int uffdio_ioctl(struct tcb *, const unsigned int, long);
+#define DECL_IOCTL(name)						\
+extern int								\
+name ## _ioctl(struct tcb *, unsigned int request, kernel_ulong_t arg)
+DECL_IOCTL(dm);
+DECL_IOCTL(file);
+DECL_IOCTL(fs_x);
+DECL_IOCTL(ptp);
+DECL_IOCTL(scsi);
+DECL_IOCTL(term);
+DECL_IOCTL(ubi);
+DECL_IOCTL(uffdio);
+#undef DECL_IOCTL
+
+extern int decode_sg_io_v4(struct tcb *, const kernel_ulong_t arg);
 
 extern int tv_nz(const struct timeval *);
 extern int tv_cmp(const struct timeval *, const struct timeval *);
@@ -704,25 +662,19 @@ extern void unwind_capture_stacktrace(struct tcb* tcp);
 #endif
 
 static inline void
-printaddr(unsigned long addr)
-{
-	printaddr_ull(addr);
-}
-
-static inline void
-printstr(struct tcb *tcp, long addr, long len)
+printstrn(struct tcb *tcp, kernel_ulong_t addr, kernel_ulong_t len)
 {
 	printstr_ex(tcp, addr, len, 0);
 }
 
-static inline int
-printflags(const struct xlat *x, unsigned int flags, const char *dflt)
+static inline void
+printstr(struct tcb *tcp, kernel_ulong_t addr)
 {
-	return printflags64(x, flags, dflt);
+	printstr_ex(tcp, addr, -1, QUOTE_0_TERMINATED);
 }
 
 static inline int
-printflags_long(const struct xlat *x, unsigned long flags, const char *dflt)
+printflags(const struct xlat *x, unsigned int flags, const char *dflt)
 {
 	return printflags64(x, flags, dflt);
 }
@@ -739,10 +691,11 @@ printxval(const struct xlat *x, const unsigned int val, const char *dflt)
 	return printxvals(val, dflt, x, NULL);
 }
 
-static inline int
-printxval_long(const struct xlat *x, const unsigned long val, const char *dflt)
+static inline void
+tprint_iov(struct tcb *tcp, kernel_ulong_t len, kernel_ulong_t addr,
+	   enum iov_decode decode_iov)
 {
-	return printxvals(val, dflt, x, NULL);
+	tprint_iov_upto(tcp, len, addr, decode_iov, -1);
 }
 
 #ifdef ALPHA
@@ -751,11 +704,15 @@ typedef struct {
 } timeval32_t;
 
 extern void print_timeval32_t(const timeval32_t *);
-extern void printrusage32(struct tcb *, long);
-extern const char *sprint_timeval32(struct tcb *tcp, long);
-extern void print_timeval32(struct tcb *tcp, long);
-extern void print_timeval32_pair(struct tcb *tcp, long);
-extern void print_itimerval32(struct tcb *tcp, long);
+extern void printrusage32(struct tcb *, kernel_ulong_t);
+extern const char *sprint_timeval32(struct tcb *tcp, kernel_ulong_t);
+extern void print_timeval32(struct tcb *tcp, kernel_ulong_t);
+extern void print_timeval32_pair(struct tcb *tcp, kernel_ulong_t);
+extern void print_itimerval32(struct tcb *tcp, kernel_ulong_t);
+#endif
+
+#ifdef HAVE_STRUCT_USER_DESC
+extern void print_user_desc(struct tcb *, kernel_ulong_t addr);
 #endif
 
 /* Strace log generation machinery.
@@ -792,31 +749,119 @@ extern unsigned current_personality;
 
 #if SUPPORTED_PERSONALITIES == 1
 # define current_wordsize PERSONALITY0_WORDSIZE
+# define current_klongsize PERSONALITY0_KLONGSIZE
 #else
 # if SUPPORTED_PERSONALITIES == 2 && PERSONALITY0_WORDSIZE == PERSONALITY1_WORDSIZE
 #  define current_wordsize PERSONALITY0_WORDSIZE
 # else
 extern unsigned current_wordsize;
 # endif
+# if SUPPORTED_PERSONALITIES == 2 && PERSONALITY0_KLONGSIZE == PERSONALITY1_KLONGSIZE
+#  define current_klongsize PERSONALITY0_KLONGSIZE
+# else
+extern unsigned current_klongsize;
+# endif
 #endif
 
-/* In many, many places we play fast and loose and use
- * tprintf("%d", (int) tcp->u_arg[N]) to print fds, pids etc.
- * We probably need to use widen_to_long() instead:
+#define ANY_WORDSIZE_LESS_THAN_KERNEL_LONG	\
+	(SIZEOF_KERNEL_LONG_T > 4		\
+	 && (SIZEOF_LONG < SIZEOF_KERNEL_LONG_T || !defined(current_wordsize)))
+
+#define DECL_PRINTNUM(name)						\
+extern bool								\
+printnum_ ## name(struct tcb *, kernel_ulong_t addr, const char *fmt)	\
+	ATTRIBUTE_FORMAT((printf, 3, 0))
+DECL_PRINTNUM(short);
+DECL_PRINTNUM(int);
+DECL_PRINTNUM(int64);
+#undef DECL_PRINTNUM
+
+#define DECL_PRINTNUM_ADDR(name)					\
+extern bool								\
+printnum_addr_ ## name(struct tcb *, kernel_ulong_t addr)
+DECL_PRINTNUM_ADDR(int);
+DECL_PRINTNUM_ADDR(int64);
+#undef DECL_PRINTNUM_ADDR
+
+#ifndef current_wordsize
+extern bool
+printnum_long_int(struct tcb *, kernel_ulong_t addr,
+		  const char *fmt_long, const char *fmt_int)
+	ATTRIBUTE_FORMAT((printf, 3, 0))
+	ATTRIBUTE_FORMAT((printf, 4, 0));
+extern bool printnum_addr_long_int(struct tcb *, kernel_ulong_t addr);
+# define printnum_slong(tcp, addr) \
+	printnum_long_int((tcp), (addr), "%" PRId64, "%d")
+# define printnum_ulong(tcp, addr) \
+	printnum_long_int((tcp), (addr), "%" PRIu64, "%u")
+# define printnum_ptr(tcp, addr) \
+	printnum_addr_long_int((tcp), (addr))
+#elif current_wordsize > 4
+# define printnum_slong(tcp, addr) \
+	printnum_int64((tcp), (addr), "%" PRId64)
+# define printnum_ulong(tcp, addr) \
+	printnum_int64((tcp), (addr), "%" PRIu64)
+# define printnum_ptr(tcp, addr) \
+	printnum_addr_int64((tcp), (addr))
+#else /* current_wordsize == 4 */
+# define printnum_slong(tcp, addr) \
+	printnum_int((tcp), (addr), "%d")
+# define printnum_ulong(tcp, addr) \
+	printnum_int((tcp), (addr), "%u")
+# define printnum_ptr(tcp, addr) \
+	printnum_addr_int((tcp), (addr))
+#endif
+
+#ifndef current_klongsize
+extern bool printnum_addr_klong_int(struct tcb *, kernel_ulong_t addr);
+# define printnum_kptr(tcp, addr) \
+	printnum_addr_klong_int((tcp), (addr))
+#elif current_klongsize > 4
+# define printnum_kptr(tcp, addr) \
+	printnum_addr_int64((tcp), (addr))
+#else /* current_klongsize == 4 */
+# define printnum_kptr(tcp, addr) \
+	printnum_addr_int((tcp), (addr))
+#endif
+
+#define DECL_PRINTPAIR(name)						\
+extern bool								\
+printpair_ ## name(struct tcb *, kernel_ulong_t addr, const char *fmt)	\
+	ATTRIBUTE_FORMAT((printf, 3, 0))
+DECL_PRINTPAIR(int);
+DECL_PRINTPAIR(int64);
+#undef DECL_PRINTPAIR
+
+static inline kernel_long_t
+truncate_klong_to_current_wordsize(const kernel_long_t v)
+{
+#if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
+	if (current_wordsize < sizeof(v)) {
+		return (int) v;
+	} else
+#endif
+	{
+		return v;
+	}
+}
+
+static inline kernel_ulong_t
+truncate_kulong_to_current_wordsize(const kernel_ulong_t v)
+{
+#if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
+	if (current_wordsize < sizeof(v)) {
+		return (unsigned int) v;
+	} else
+#endif
+	{
+		return v;
+	}
+}
+
+/*
+ * Cast a pointer or a pointer-sized integer to kernel_ulong_t.
  */
-#if SUPPORTED_PERSONALITIES > 1 && SIZEOF_LONG > 4
-# define widen_to_long(v) (current_wordsize == 4 ? (long)(int32_t)(v) : (long)(v))
-#else
-# define widen_to_long(v) ((long)(v))
-#endif
-
-#if SUPPORTED_PERSONALITIES > 1 && SIZEOF_LONG > 4
-# define widen_to_ulong(v) \
-	(current_wordsize == 4 ? (unsigned long) (uint32_t) (v) : \
-		(unsigned long) (v))
-#else
-# define widen_to_ulong(v) ((unsigned long)(v))
-#endif
+#define ptr_to_kulong(v) ((kernel_ulong_t) (unsigned long) (v))
 
 /*
  * Zero-extend a signed integer type to unsigned long long.
@@ -862,7 +907,7 @@ extern unsigned nioctlents;
 
 extern const unsigned int nsyscall_vec[SUPPORTED_PERSONALITIES];
 extern const struct_sysent *const sysent_vec[SUPPORTED_PERSONALITIES];
-extern struct fault_opts *fault_vec[SUPPORTED_PERSONALITIES];
+extern struct inject_opts *inject_vec[SUPPORTED_PERSONALITIES];
 
 #ifdef IN_MPERS_BOOTSTRAP
 /* Transform multi-line MPERS_PRINTER_DECL statements to one-liners.  */
@@ -876,18 +921,25 @@ extern struct fault_opts *fault_vec[SUPPORTED_PERSONALITIES];
 # define MPERS_PRINTER_DECL(type, name, ...) type MPERS_FUNC_NAME(name)(__VA_ARGS__)
 #endif /* !IN_MPERS_BOOTSTRAP */
 
-/*
- * If you need non-NULL sysent[scno].sys_func, non-NULL sysent[scno].sys_name,
- * and non-indirect sysent[scno].sys_flags.
- */
-#define SCNO_IS_VALID(scno) \
-	((unsigned long)(scno) < nsyscalls \
-	 && sysent[scno].sys_func \
-	 && !(sysent[scno].sys_flags & TRACE_INDIRECT_SUBCALL))
+/* Checks that sysent[scno] is not out of range. */
+static inline bool
+scno_in_range(kernel_ulong_t scno)
+{
+	return scno < nsyscalls;
+}
 
-/* Only ensures that sysent[scno] isn't out of range */
-#define SCNO_IN_RANGE(scno) \
-	((unsigned long)(scno) < nsyscalls)
+/*
+ * Checks whether scno is not out of range,
+ * its corresponding sysent[scno].sys_func is non-NULL,
+ * and its sysent[scno].sys_flags has no TRACE_INDIRECT_SUBCALL flag set.
+ */
+static inline bool
+scno_is_valid(kernel_ulong_t scno)
+{
+	return scno_in_range(scno)
+	       && sysent[scno].sys_func
+	       && !(sysent[scno].sys_flags & TRACE_INDIRECT_SUBCALL);
+}
 
 #define MPERS_FUNC_NAME__(prefix, name) prefix ## name
 #define MPERS_FUNC_NAME_(prefix, name) MPERS_FUNC_NAME__(prefix, name)
@@ -897,6 +949,16 @@ extern struct fault_opts *fault_vec[SUPPORTED_PERSONALITIES];
 
 #define SYS_FUNC(syscall_name) int SYS_FUNC_NAME(sys_ ## syscall_name)(struct tcb *tcp)
 
+#if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
+# define PRI_kl "ll"
+#else
+# define PRI_kl "l"
+#endif
+
+#define PRI_kld PRI_kl"d"
+#define PRI_klu PRI_kl"u"
+#define PRI_klx PRI_kl"x"
+
 /*
  * The kernel used to define 64-bit types on 64-bit systems on a per-arch
  * basis.  Some architectures would use unsigned long and others would use
