@@ -1,3 +1,35 @@
+/*
+ * Support for decoding of DM_* ioctl commands.
+ *
+ * Copyright (c) 2016 Mikulas Patocka <mpatocka@redhat.com>
+ * Copyright (c) 2016 Masatake Yamato <yamato@redhat.com>
+ * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 3. The name of the author may not be used to endorse or promote products
+ *    derived from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+ * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ */
+
 #include "defs.h"
 
 #ifdef HAVE_LINUX_DM_IOCTL_H
@@ -5,8 +37,6 @@
 # include <linux/dm-ioctl.h>
 # include <linux/ioctl.h>
 
-# include <sys/sysmacros.h>
-
 # if DM_VERSION_MAJOR == 4
 
 /* Definitions for command which have been added later */
@@ -31,9 +61,10 @@ dm_decode_device(const unsigned int code, const struct dm_ioctl *ioc)
 	case DM_LIST_VERSIONS:
 		break;
 	default:
-		if (ioc->dev)
-			tprintf(", dev=makedev(%u, %u)",
-				major(ioc->dev), minor(ioc->dev));
+		if (ioc->dev) {
+			tprints(", dev=");
+			print_dev_t(ioc->dev);
+		}
 		if (ioc->name[0]) {
 			tprints(", name=");
 			print_quoted_string(ioc->name, DM_NAME_LEN,
@@ -102,8 +133,8 @@ dm_decode_flags(const struct dm_ioctl *ioc)
 }
 
 static void
-dm_decode_dm_target_spec(struct tcb *tcp, unsigned long addr,
-			 const struct dm_ioctl *ioc)
+dm_decode_dm_target_spec(struct tcb *const tcp, const kernel_ulong_t addr,
+			 const struct dm_ioctl *const ioc)
 {
 	static const uint32_t target_spec_size =
 		sizeof(struct dm_target_spec);
@@ -171,14 +202,14 @@ dm_print_dev(struct tcb *tcp, void *dev_ptr, size_t dev_size, void *dummy)
 {
 	uint64_t *dev = (uint64_t *) dev_ptr;
 
-	tprintf("makedev(%u, %u)", major(*dev), minor(*dev));
+	print_dev_t(*dev);
 
 	return 1;
 }
 
 static void
-dm_decode_dm_target_deps(struct tcb *tcp, unsigned long addr,
-			 const struct dm_ioctl *ioc)
+dm_decode_dm_target_deps(struct tcb *const tcp, const kernel_ulong_t addr,
+			 const struct dm_ioctl *const ioc)
 {
 	static const uint32_t target_deps_dev_offs =
 		offsetof(struct dm_target_deps, dev);
@@ -220,8 +251,8 @@ misplaced:
 }
 
 static void
-dm_decode_dm_name_list(struct tcb *tcp, unsigned long addr,
-		       const struct dm_ioctl *ioc)
+dm_decode_dm_name_list(struct tcb *const tcp, const kernel_ulong_t addr,
+		       const struct dm_ioctl *const ioc)
 {
 	static const uint32_t name_list_name_offs =
 		offsetof(struct dm_name_list, name);
@@ -255,8 +286,10 @@ dm_decode_dm_name_list(struct tcb *tcp, unsigned long addr,
 			break;
 		}
 
-		tprintf("{dev=makedev(%u, %u), name=", major(s.dev),
-			minor(s.dev));
+		tprints("{dev=");
+		print_dev_t(s.dev);
+
+		tprints("name=");
 		printstr_ex(tcp, addr + offset_end, ioc->data_size - offset_end,
 			    QUOTE_0_TERMINATED);
 		tprints("}");
@@ -276,8 +309,8 @@ misplaced:
 }
 
 static void
-dm_decode_dm_target_versions(struct tcb *tcp, unsigned long addr,
-			     const struct dm_ioctl *ioc)
+dm_decode_dm_target_versions(struct tcb *const tcp, const kernel_ulong_t addr,
+			     const struct dm_ioctl *const ioc)
 {
 	static const uint32_t target_vers_name_offs =
 		offsetof(struct dm_target_versions, name);
@@ -328,8 +361,8 @@ misplaced:
 }
 
 static void
-dm_decode_dm_target_msg(struct tcb *tcp, unsigned long addr,
-		        const struct dm_ioctl *ioc)
+dm_decode_dm_target_msg(struct tcb *const tcp, const kernel_ulong_t addr,
+		        const struct dm_ioctl *const ioc)
 {
 	static const uint32_t target_msg_message_offs =
 		offsetof(struct dm_target_msg, message);
@@ -359,8 +392,8 @@ dm_decode_dm_target_msg(struct tcb *tcp, unsigned long addr,
 }
 
 static void
-dm_decode_string(struct tcb *tcp, unsigned long addr,
-		 const struct dm_ioctl *ioc)
+dm_decode_string(struct tcb *const tcp, const kernel_ulong_t addr,
+		 const struct dm_ioctl *const ioc)
 {
 	uint32_t offset = ioc->data_start;
 
@@ -396,7 +429,8 @@ dm_ioctl_has_params(const unsigned int code)
 }
 
 static int
-dm_known_ioctl(struct tcb *tcp, const unsigned int code, long arg)
+dm_known_ioctl(struct tcb *const tcp, const unsigned int code,
+	       const kernel_ulong_t arg)
 {
 	struct dm_ioctl *ioc = NULL;
 	struct dm_ioctl *entering_ioc = NULL;
@@ -516,7 +550,7 @@ dm_known_ioctl(struct tcb *tcp, const unsigned int code, long arg)
 }
 
 int
-dm_ioctl(struct tcb *tcp, const unsigned int code, long arg)
+dm_ioctl(struct tcb *const tcp, const unsigned int code, const kernel_ulong_t arg)
 {
 	switch (code) {
 	case DM_VERSION:
@@ -544,7 +578,7 @@ dm_ioctl(struct tcb *tcp, const unsigned int code, long arg)
 # else /* !(DM_VERSION_MAJOR == 4) */
 
 int
-dm_ioctl(struct tcb *tcp, const unsigned int code, long arg)
+dm_ioctl(struct tcb *const tcp, const unsigned int code, const kernel_ulong_t arg)
 {
 	return 0;
 }
