@@ -109,9 +109,9 @@ SYS_FUNC(epoll_pwait)
 	epoll_wait_common(tcp);
 	if (exiting(tcp)) {
 		tprints(", ");
-		/* NB: kernel requires arg[5] == NSIG / 8 */
+		/* NB: kernel requires arg[5] == NSIG_BYTES */
 		print_sigset_addr_len(tcp, tcp->u_arg[4], tcp->u_arg[5]);
-		tprintf(", %lu", tcp->u_arg[5]);
+		tprintf(", %" PRI_klu, tcp->u_arg[5]);
 	}
 	return 0;
 }
