@@ -34,8 +34,8 @@ typedef struct seccomp_fprog seccomp_fprog_t;
 
 #include MPERS_DEFS
 
-MPERS_PRINTER_DECL(bool, fetch_seccomp_fprog,
-		   struct tcb *tcp, const long addr, void *p)
+MPERS_PRINTER_DECL(bool, fetch_seccomp_fprog, struct tcb *const tcp,
+		   const kernel_ulong_t addr, void *const p)
 {
 	struct seccomp_fprog *pfp = p;
 	seccomp_fprog_t mfp;
