@@ -57,8 +57,8 @@ SYS_FUNC(msgget)
 }
 
 static void
-tprint_msgsnd(struct tcb *tcp, const long addr, const unsigned long count,
-	      const unsigned long flags)
+tprint_msgsnd(struct tcb *const tcp, const kernel_ulong_t addr,
+	      const kernel_ulong_t count, const unsigned int flags)
 {
 	tprint_msgbuf(tcp, addr, count);
 	printflags(ipc_msg_flags, flags, "MSG_???");
@@ -78,15 +78,16 @@ SYS_FUNC(msgsnd)
 }
 
 static void
-tprint_msgrcv(struct tcb *tcp, const long addr, const unsigned long count,
-	      const long msgtyp)
+tprint_msgrcv(struct tcb *const tcp, const kernel_ulong_t addr,
+	      const kernel_ulong_t count, const kernel_ulong_t msgtyp)
 {
 	tprint_msgbuf(tcp, addr, count);
-	tprintf("%ld, ", msgtyp);
+	tprintf("%" PRI_kld ", ", msgtyp);
 }
 
 static int
-fetch_msgrcv_args(struct tcb *tcp, const long addr, unsigned long *pair)
+fetch_msgrcv_args(struct tcb *const tcp, const kernel_ulong_t addr,
+		  kernel_ulong_t *const pair)
 {
 	if (current_wordsize == sizeof(*pair)) {
 		if (umoven_or_printaddr(tcp, addr, 2 * sizeof(*pair), pair))
@@ -117,10 +118,10 @@ SYS_FUNC(msgrcv)
 				tprint_msgrcv(tcp, tcp->u_arg[3],
 					      tcp->u_arg[1], tcp->u_arg[4]);
 			} else {
-				unsigned long pair[2];
+				kernel_ulong_t pair[2];
 
 				if (fetch_msgrcv_args(tcp, tcp->u_arg[3], pair))
-					tprintf(", %lu, ", tcp->u_arg[1]);
+					tprintf(", %" PRI_klu ", ", tcp->u_arg[1]);
 				else
 					tprint_msgrcv(tcp, pair[0],
 						      tcp->u_arg[1], pair[1]);
