@@ -57,7 +57,8 @@ print_sembuf(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 #endif
 
 static void
-tprint_sembuf_array(struct tcb *tcp, const long addr, const unsigned int count)
+tprint_sembuf_array(struct tcb *const tcp, const kernel_ulong_t addr,
+		    const unsigned int count)
 {
 #if defined HAVE_SYS_SEM_H || defined HAVE_LINUX_SEM_H
 	struct sembuf sb;
@@ -125,7 +126,7 @@ SYS_FUNC(semctl)
 	   ) {
 		printnum_ptr(tcp, tcp->u_arg[3]);
 	} else {
-		tprintf("%#lx", tcp->u_arg[3]);
+		printaddr(tcp->u_arg[3]);
 	}
 	return RVAL_DECODED;
 }
