@@ -267,13 +267,13 @@
 [274] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [275] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [276] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[277] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[278] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[279] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[280] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[281] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[282] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[283] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[277] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[278] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[279] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[280] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[281] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[282] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[283] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [284] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [285] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [286] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
