@@ -473,6 +473,6 @@
 [508] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [509] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [510] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[511] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[512] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[513] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[511] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[512] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[513] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
