@@ -341,15 +341,18 @@
 [313] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [314] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [315] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[316] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[317] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[318] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[319] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[320] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[316] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[317] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[318] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[319] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[320] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
 [321] = { 4,	TN,		SEN(accept4),			"accept4"		},
-[322] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[323] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[322] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[323] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [324] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [325] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [326] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [327] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
+[328] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
+[329] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
+[330] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
