@@ -413,8 +413,8 @@
 [385] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [386] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [387] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[388] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[389] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[390] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[391] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[392] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[388] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[389] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[390] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[391] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[392] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
