@@ -340,13 +340,13 @@
 [335] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [336] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [337] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[338] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[339] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[340] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[341] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[342] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[343] = { 2,	0,		SEN(membarrier),		"membarrier",		},
-[344] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
+[338] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[339] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[340] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[341] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[342] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[343] = { 2,	0,		SEN(membarrier),		"membarrier"		},
+[344] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
 [345] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [346] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [347] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
