@@ -379,11 +379,11 @@
 [351] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [352] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [353] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[354] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[355] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[356] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[357] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[358] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[354] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[355] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[356] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[357] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[358] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
 [359] = { 3,	TN,		SEN(socket),			"socket"		},
 [360] = { 4,	TN,		SEN(socketpair),		"socketpair"		},
 [361] = { 3,	TN,		SEN(bind),			"bind"			},
@@ -399,8 +399,8 @@
 [371] = { 6,	TN,		SEN(recvfrom),			"recvfrom"		},
 [372] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
 [373] = { 2,	TN,		SEN(shutdown),			"shutdown"		},
-[374] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[375] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[374] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[375] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [376] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [377] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [378] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
