@@ -377,10 +377,10 @@
 [349] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [350] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [351] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[352] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[353] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[354] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[355] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[352] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[353] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[354] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[355] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
 [356] = { 3,	TN,		SEN(socket),			"socket"		},
 [357] = { 4,	TN,		SEN(socketpair),		"socketpair"		},
 [358] = { 3,	TN,		SEN(bind),			"bind"			},
@@ -398,8 +398,8 @@
 [370] = { 2,	TN,		SEN(shutdown),			"shutdown"		},
 [371] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
 [372] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
-[373] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[374] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[373] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[374] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [375] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [376] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [377] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
