@@ -409,11 +409,17 @@
 [381] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [382] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [383] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[384] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[385] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[386] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[387] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[388] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[389] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[390] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[384] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[385] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[386] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[387] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[388] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[389] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[390] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [391] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
+[392] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
+[393] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
+[394] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
+[395] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
+[396] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
+[397] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
