@@ -6,8 +6,8 @@ arch_sigreturn(struct tcb *tcp)
 	 * offsetof(struct sigframe, sf_mask) ==
 	 * sizeof(sf_ass) + sizeof(sf_pad) + sizeof(struct sigcontext)
 	 */
-	const long addr = mips_REG_SP + 6 * 4 +
-			  sizeof(struct sigcontext);
+	const kernel_ulong_t addr = mips_REG_SP + 6 * 4 +
+				   sizeof(struct sigcontext);
 #else
 	/*
 	 * This decodes rt_sigreturn.
@@ -16,11 +16,11 @@ arch_sigreturn(struct tcb *tcp)
 	 * offsetof(struct rt_sigframe, rs_uc) ==
 	 * sizeof(sf_ass) + sizeof(sf_pad) + sizeof(struct siginfo)
 	 */
-	const long addr = mips_REG_SP + 6 * 4 + 128 +
-			  offsetof(struct ucontext, uc_sigmask);
+	const kernel_ulong_t addr = mips_REG_SP + 6 * 4 + 128 +
+				   offsetof(struct ucontext, uc_sigmask);
 #endif
 
 	tprints("{mask=");
-	print_sigset_addr_len(tcp, addr, NSIG / 8);
+	print_sigset_addr_len(tcp, addr, NSIG_BYTES);
 	tprints("}");
 }
