@@ -316,13 +316,13 @@
 [6313] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [6314] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [6315] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[6316] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[6317] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[6318] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[6319] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[6320] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[6321] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[6322] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[6316] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[6317] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[6318] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[6319] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[6320] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[6321] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[6322] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [6323] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [6324] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [6325] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
