@@ -312,13 +312,13 @@
 [5309] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [5310] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [5311] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[5312] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[5313] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[5314] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[5315] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[5316] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[5317] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[5318] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[5312] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[5313] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[5314] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[5315] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[5316] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[5317] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[5318] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [5319] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [5320] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [5321] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
