@@ -352,13 +352,13 @@
 [4349] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [4350] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [4351] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[4352] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[4353] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[4354] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[4355] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[4356] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[4357] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[4358] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[4352] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[4353] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[4354] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[4355] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[4356] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[4357] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[4358] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [4359] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [4360] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [4361] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
