@@ -379,14 +379,14 @@
 [355] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [356] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [357] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[358] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[359] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[360] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[361] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[362] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
+[358] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[359] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[360] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[361] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[362] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
 [363] = { 0,	0,		SEN(printargs),			"switch_endian"		},
-[364] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[365] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[364] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[365] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [366] = { 3,	TI,		SEN(semop),			"semop"			},
 [367] = { 3,	TI,		SEN(semget),			"semget"		},
 [368] = { 4,	TI,		SEN(semctl),			"semctl"		},
@@ -403,6 +403,7 @@
 [379] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [380] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [381] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
+[382] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
 
 #define SYS_socket_subcall	400
 #include "subcall.h"
