@@ -360,15 +360,15 @@
 [345] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [346] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [347] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[348] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[349] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[350] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[351] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[352] = { 3,	0,		SEN(printargs),			"s390_pci_mmio_write",	},
-[353] = { 3,	0,		SEN(printargs),			"s390_pci_mmio_read",	},
-[354] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[355] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[356] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[348] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[349] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[350] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[351] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[352] = { 3,	0,		SEN(printargs),			"s390_pci_mmio_write"	},
+[353] = { 3,	0,		SEN(printargs),			"s390_pci_mmio_read"	},
+[354] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[355] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[356] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [357] = { 5,	TN,		SEN(recvmmsg),			"recvmmsg"		},
 [358] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [359] = { 3,	TN,		SEN(socket),			"socket"		},
