@@ -344,13 +344,13 @@
 [343] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [344] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [345] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[346] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[347] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[348] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[349] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[350] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[351] = { 2,	0,		SEN(membarrier),		"membarrier",		},
-[352] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
+[346] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[347] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[348] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[349] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[350] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[351] = { 2,	0,		SEN(membarrier),		"membarrier"		},
+[352] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
 [353] = { 3,	TN,		SEN(bind),			"bind"			},
 [354] = { 2,	TN,		SEN(listen),			"listen"		},
 [355] = { 5,	TN,		SEN(setsockopt),		"setsockopt"		},
