@@ -315,14 +315,14 @@
 [314] = { 3,	0,		SEN(sched_setattr),		"sched_setattr"		},
 [315] = { 4,	0,		SEN(sched_getattr),		"sched_getattr"		},
 [316] = { 5,	TD|TF,		SEN(renameat2),			"renameat2"		},
-[317] = { 3,	0,		SEN(seccomp),			"seccomp",		},
-[318] = { 3,	0,		SEN(getrandom),			"getrandom",		},
-[319] = { 2,	TD,		SEN(memfd_create),		"memfd_create",		},
-[320] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load",	},
-[321] = { 3,	TD,		SEN(bpf),			"bpf",			},
-[322] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat",		},
-[323] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd",		},
-[324] = { 2,	0,		SEN(membarrier),		"membarrier",		},
+[317] = { 3,	0,		SEN(seccomp),			"seccomp"		},
+[318] = { 3,	0,		SEN(getrandom),			"getrandom"		},
+[319] = { 2,	TD,		SEN(memfd_create),		"memfd_create"		},
+[320] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
+[321] = { 3,	TD,		SEN(bpf),			"bpf"			},
+[322] = { 5,	TD|TF|TP|SE|SI,	SEN(execveat),			"execveat"		},
+[323] = { 1,	TD,		SEN(userfaultfd),		"userfaultfd"		},
+[324] = { 2,	0,		SEN(membarrier),		"membarrier"		},
 [325] = { 3,	TM,		SEN(mlock2),			"mlock2"		},
 [326] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [327] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
