@@ -37,6 +37,9 @@ extern const struct xlat evdev_switch[];
 extern const struct xlat evdev_sync[];
 extern const struct xlat msgctl_flags[];
 extern const struct xlat shmctl_flags[];
+extern const struct xlat loop_cmds[];
+extern const struct xlat loop_flags_options[];
+extern const struct xlat loop_crypt_type_options[];
 extern const struct xlat mtd_mode_options[];
 extern const struct xlat mtd_file_mode_options[];
 extern const struct xlat mtd_type_options[];
@@ -59,7 +62,11 @@ extern const struct xlat sigsegv_codes[];
 extern const struct xlat sigsys_codes[];
 extern const struct xlat sigtrap_codes[];
 extern const struct xlat sigemt_codes[];
+extern const struct xlat sg_io_info[];
+extern const struct xlat sg_io_dxfer_direction[];
+extern const struct xlat sg_io_flags[];
 extern const struct xlat sigaltstack_flags[];
+extern const struct xlat iffflags[];
 extern const struct xlat v4l2_device_capabilities_flags[];
 extern const struct xlat v4l2_buf_types[];
 extern const struct xlat v4l2_format_description_flags[];
