@@ -48,8 +48,8 @@ SYS_FUNC(mq_open)
 SYS_FUNC(mq_timedsend)
 {
 	tprintf("%d, ", (int) tcp->u_arg[0]);
-	printstr(tcp, tcp->u_arg[1], tcp->u_arg[2]);
-	tprintf(", %llu, %u, ", getarg_ull(tcp, 2),
+	printstrn(tcp, tcp->u_arg[1], tcp->u_arg[2]);
+	tprintf(", %" PRI_klu ", %u, ", tcp->u_arg[2],
 		(unsigned int) tcp->u_arg[3]);
 	print_timespec(tcp, tcp->u_arg[4]);
 	return RVAL_DECODED;
@@ -60,11 +60,11 @@ SYS_FUNC(mq_timedreceive)
 	if (entering(tcp)) {
 		tprintf("%d, ", (int) tcp->u_arg[0]);
 	} else {
-		if (!syserror(tcp) && (tcp->u_rval >= 0))
-			printstr(tcp, tcp->u_arg[1], tcp->u_rval);
-		else
+		if (syserror(tcp))
 			printaddr(tcp->u_arg[1]);
-		tprintf(", %llu, ", getarg_ull(tcp, 2));
+		else
+			printstrn(tcp, tcp->u_arg[1], tcp->u_rval);
+		tprintf(", %" PRI_klu ", ", tcp->u_arg[2]);
 		printnum_int(tcp, tcp->u_arg[3], "%u");
 		tprintf(", ");
 		/*
