@@ -61,7 +61,7 @@ free_pea_desc(void *pea_desc_ptr)
 }
 
 static int
-fetch_perf_event_attr(struct tcb *tcp, unsigned long addr)
+fetch_perf_event_attr(struct tcb *const tcp, const kernel_ulong_t addr)
 {
 	struct pea_desc *desc;
 	struct perf_event_attr *attr;
@@ -118,7 +118,7 @@ fetch_perf_event_attr(struct tcb *tcp, unsigned long addr)
 	} while (0)
 
 static void
-print_perf_event_attr(struct tcb *tcp, unsigned long addr)
+print_perf_event_attr(struct tcb *const tcp, const kernel_ulong_t addr)
 {
 	static const char *precise_ip_desc[] = {
 		"arbitrary skid",
@@ -321,8 +321,8 @@ print_perf_event_attr(struct tcb *tcp, unsigned long addr)
 	 * are not aware about.
 	 */
 	if (attr->__reserved_1)
-		tprintf(", __reserved_1=%#llx /* Bits 63..28 */",
-		        (unsigned long long) attr->__reserved_1);
+		tprintf(", __reserved_1=%#" PRIx64 " /* Bits 63..28 */",
+		        (uint64_t) attr->__reserved_1);
 
 	if (attr->watermark)
 		tprintf(", wakeup_watermark=%u", attr->wakeup_watermark);
@@ -423,7 +423,7 @@ SYS_FUNC(perf_event_open)
 		(int) tcp->u_arg[1],
 		(int) tcp->u_arg[2],
 		(int) tcp->u_arg[3]);
-	printflags_long(perf_event_open_flags, tcp->u_arg[4], "PERF_FLAG_???");
+	printflags64(perf_event_open_flags, tcp->u_arg[4], "PERF_FLAG_???");
 
 	return RVAL_DECODED | RVAL_FD;
 }
