@@ -33,12 +33,15 @@
 
 #include "defs.h"
 #include "native_defs.h"
+#include "nsig.h"
 #include <sys/param.h>
-#include <signal.h>
 
 /* for struct iovec */
 #include <sys/uio.h>
 
+/* for __X32_SYSCALL_BIT */
+#include <asm/unistd.h>
+
 #include "regs.h"
 #include "ptrace.h"
 
@@ -63,11 +66,6 @@
 # define NT_PRSTATUS 1
 #endif
 
-#ifndef NSIG
-# warning: NSIG is not defined, using 32
-# define NSIG 32
-#endif
-
 #include "syscall.h"
 
 /* Define these shorthand notations to simplify the syscallent files. */
@@ -82,6 +80,7 @@
 #define MA MAX_ARGS
 #define SI STACKTRACE_INVALIDATE_CACHE
 #define SE STACKTRACE_CAPTURE_ON_ENTER
+#define CST COMPAT_SYSCALL_TYPES
 
 #define SEN(syscall_name) SEN_ ## syscall_name, SYS_FUNC_NAME(sys_ ## syscall_name)
 
@@ -116,6 +115,7 @@ static const struct_sysent sysent2[] = {
 #undef MA
 #undef SI
 #undef SE
+#undef CST
 
 /*
  * `ioctlent[012].h' files are automatically generated by the auxiliary
@@ -257,6 +257,17 @@ static const int personality_wordsize[SUPPORTED_PERSONALITIES] = {
 };
 # endif
 
+# ifndef current_klongsize
+unsigned current_klongsize;
+static const int personality_klongsize[SUPPORTED_PERSONALITIES] = {
+	PERSONALITY0_KLONGSIZE,
+	PERSONALITY1_KLONGSIZE,
+#  if SUPPORTED_PERSONALITIES > 2
+	PERSONALITY2_KLONGSIZE,
+#  endif
+};
+# endif
+
 void
 set_personality(int personality)
 {
@@ -301,6 +312,9 @@ set_personality(int personality)
 # ifndef current_wordsize
 	current_wordsize = personality_wordsize[personality];
 # endif
+# ifndef current_klongsize
+	current_klongsize = personality_klongsize[personality];
+# endif
 }
 
 static void
@@ -345,7 +359,7 @@ decode_socket_subcall(struct tcb *tcp)
 	if (call < 1 || call >= SYS_socket_nsubcalls)
 		return;
 
-	const unsigned long scno = SYS_socket_subcall + call;
+	const kernel_ulong_t scno = SYS_socket_subcall + call;
 	const unsigned int nargs = sysent[scno].nargs;
 	uint64_t buf[nargs];
 
@@ -407,7 +421,7 @@ decode_ipc_subcall(struct tcb *tcp)
 static void
 decode_mips_subcall(struct tcb *tcp)
 {
-	if (!SCNO_IS_VALID(tcp->u_arg[0]))
+	if (!scno_is_valid(tcp->u_arg[0]))
 		return;
 	tcp->scno = tcp->u_arg[0];
 	tcp->qual_flg = qual_flags(tcp->scno);
@@ -475,11 +489,10 @@ dumpio(struct tcb *tcp)
 		case SEN_pwritev:
 		case SEN_pwritev2:
 		case SEN_vmsplice:
-			dumpiov(tcp, tcp->u_arg[2], tcp->u_arg[1]);
+			dumpiov_upto(tcp, tcp->u_arg[2], tcp->u_arg[1], -1);
 			break;
 		case SEN_sendmsg:
-			dumpiov_in_msghdr(tcp, tcp->u_arg[1],
-					  (unsigned long) -1L);
+			dumpiov_in_msghdr(tcp, tcp->u_arg[1], -1);
 			break;
 		case SEN_sendmmsg:
 			dumpiov_in_mmsghdr(tcp, tcp->u_arg[1]);
@@ -492,10 +505,10 @@ dumpio(struct tcb *tcp)
  * Shuffle syscall numbers so that we don't have huge gaps in syscall table.
  * The shuffling should be an involution: shuffle_scno(shuffle_scno(n)) == n.
  */
-#if defined(ARM) || defined(AARCH64) /* So far only 32-bit ARM needs this */
-static long
-shuffle_scno(unsigned long scno)
+static kernel_ulong_t
+shuffle_scno(kernel_ulong_t scno)
 {
+#if defined(ARM) || defined(AARCH64) /* So far only 32-bit ARM needs this */
 	if (scno < ARM_FIRST_SHUFFLED_SYSCALL)
 		return scno;
 
@@ -505,7 +518,7 @@ shuffle_scno(unsigned long scno)
 	if (scno == 0x000ffff0)
 		return ARM_FIRST_SHUFFLED_SYSCALL;
 
-#define ARM_SECOND_SHUFFLED_SYSCALL (ARM_FIRST_SHUFFLED_SYSCALL + 1)
+# define ARM_SECOND_SHUFFLED_SYSCALL (ARM_FIRST_SHUFFLED_SYSCALL + 1)
 	/*
 	 * Is it ARM specific syscall?
 	 * Swap [0x000f0000, 0x000f0000 + LAST_SPECIAL] range
@@ -518,12 +531,10 @@ shuffle_scno(unsigned long scno)
 	if (scno <= ARM_SECOND_SHUFFLED_SYSCALL + ARM_LAST_SPECIAL_SYSCALL) {
 		return scno + 0x000f0000 - ARM_SECOND_SHUFFLED_SYSCALL;
 	}
+#endif /* ARM || AARCH64 */
 
 	return scno;
 }
-#else
-# define shuffle_scno(scno) ((long)(scno))
-#endif
 
 const char *
 err_name(unsigned long err)
@@ -545,32 +556,33 @@ clear_regs(void)
 static int get_syscall_args(struct tcb *);
 static int get_syscall_result(struct tcb *);
 static int arch_get_scno(struct tcb *tcp);
-static int arch_set_scno(struct tcb *, long);
+static int arch_set_scno(struct tcb *, kernel_ulong_t);
 static void get_error(struct tcb *, const bool);
 static int arch_set_error(struct tcb *);
+static int arch_set_success(struct tcb *);
 
-struct fault_opts *fault_vec[SUPPORTED_PERSONALITIES];
+struct inject_opts *inject_vec[SUPPORTED_PERSONALITIES];
 
-static struct fault_opts *
-tcb_fault_opts(struct tcb *tcp)
+static struct inject_opts *
+tcb_inject_opts(struct tcb *tcp)
 {
-	return (SCNO_IN_RANGE(tcp->scno) && tcp->fault_vec[current_personality])
-	       ? &tcp->fault_vec[current_personality][tcp->scno] : NULL;
+	return (scno_in_range(tcp->scno) && tcp->inject_vec[current_personality])
+	       ? &tcp->inject_vec[current_personality][tcp->scno] : NULL;
 }
 
 
 static long
-inject_syscall_fault_entering(struct tcb *tcp)
+tamper_with_syscall_entering(struct tcb *tcp, unsigned int *signo)
 {
-	if (!tcp->fault_vec[current_personality]) {
-		tcp->fault_vec[current_personality] =
-			xcalloc(nsyscalls, sizeof(**fault_vec));
-		memcpy(tcp->fault_vec[current_personality],
-		       fault_vec[current_personality],
-		       nsyscalls * sizeof(**fault_vec));
+	if (!tcp->inject_vec[current_personality]) {
+		tcp->inject_vec[current_personality] =
+			xcalloc(nsyscalls, sizeof(**inject_vec));
+		memcpy(tcp->inject_vec[current_personality],
+		       inject_vec[current_personality],
+		       nsyscalls * sizeof(**inject_vec));
 	}
 
-	struct fault_opts *opts = tcb_fault_opts(tcp);
+	struct inject_opts *opts = tcb_inject_opts(tcp);
 
 	if (!opts || opts->first == 0)
 		return 0;
@@ -582,29 +594,49 @@ inject_syscall_fault_entering(struct tcb *tcp)
 
 	opts->first = opts->step;
 
-	if (!arch_set_scno(tcp, -1))
-		tcp->flags |= TCB_FAULT_INJ;
+	if (opts->signo > 0)
+		*signo = opts->signo;
+	if (opts->rval != INJECT_OPTS_RVAL_DEFAULT && !arch_set_scno(tcp, -1))
+		tcp->flags |= TCB_TAMPERED;
 
 	return 0;
 }
 
 static long
-update_syscall_fault_exiting(struct tcb *tcp)
+tamper_with_syscall_exiting(struct tcb *tcp)
 {
-	struct fault_opts *opts = tcb_fault_opts(tcp);
+	struct inject_opts *opts = tcb_inject_opts(tcp);
 
-	if (opts && opts->err && tcp->u_error != opts->err) {
-		unsigned long u_error = tcp->u_error;
-		tcp->u_error = opts->err;
-		if (arch_set_error(tcp))
-			tcp->u_error = u_error;
+	if (!opts)
+		return 0;
+
+	if (opts->rval >= 0) {
+		kernel_long_t u_rval = tcp->u_rval;
+
+		tcp->u_rval = opts->rval;
+		if (arch_set_success(tcp)) {
+			tcp->u_rval = u_rval;
+		} else {
+			tcp->u_error = 0;
+		}
+	} else {
+		unsigned long new_error = -opts->rval;
+
+		if (new_error != tcp->u_error && new_error <= MAX_ERRNO_VALUE) {
+			unsigned long u_error = tcp->u_error;
+
+			tcp->u_error = new_error;
+			if (arch_set_error(tcp)) {
+				tcp->u_error = u_error;
+			}
+		}
 	}
 
 	return 0;
 }
 
 static int
-trace_syscall_entering(struct tcb *tcp)
+trace_syscall_entering(struct tcb *tcp, unsigned int *sig)
 {
 	int res, scno_good;
 
@@ -646,7 +678,7 @@ trace_syscall_entering(struct tcb *tcp)
 
 	/* Restrain from fault injection while the trace executes strace code. */
 	if (hide_log(tcp)) {
-		tcp->qual_flg &= ~QUAL_FAULT;
+		tcp->qual_flg &= ~QUAL_INJECT;
 	}
 
 	switch (tcp->s_ent->sen) {
@@ -674,8 +706,8 @@ trace_syscall_entering(struct tcb *tcp)
 		goto ret;
 	}
 
-	if (tcp->qual_flg & QUAL_FAULT)
-		inject_syscall_fault_entering(tcp);
+	if (tcp->qual_flg & QUAL_INJECT)
+		tamper_with_syscall_entering(tcp, sig);
 
 	if (cflag == CFLAG_ONLY_STATS) {
 		res = 0;
@@ -707,9 +739,9 @@ trace_syscall_entering(struct tcb *tcp)
 }
 
 static bool
-syscall_fault_injected(struct tcb *tcp)
+syscall_tampered(struct tcb *tcp)
 {
-	return tcp->flags & TCB_FAULT_INJ;
+	return tcp->flags & TCB_TAMPERED;
 }
 
 static int
@@ -739,8 +771,8 @@ trace_syscall_exiting(struct tcb *tcp)
 	if (filtered(tcp) || hide_log(tcp))
 		goto ret;
 
-	if (syserror(tcp) && syscall_fault_injected(tcp))
-		update_syscall_fault_exiting(tcp);
+	if (syserror(tcp) && syscall_tampered(tcp))
+		tamper_with_syscall_exiting(tcp);
 
 	if (cflag) {
 		count_syscall(tcp, &tv);
@@ -772,7 +804,7 @@ trace_syscall_exiting(struct tcb *tcp)
 		tabto();
 		tprints("= ? <unavailable>\n");
 		line_ended();
-		tcp->flags &= ~(TCB_INSYSCALL | TCB_FAULT_INJ);
+		tcp->flags &= ~(TCB_INSYSCALL | TCB_TAMPERED);
 		tcp->sys_func_rval = 0;
 		free_tcb_priv_data(tcp);
 		return res;
@@ -806,11 +838,11 @@ trace_syscall_exiting(struct tcb *tcp)
 	if (tcp->qual_flg & QUAL_RAW) {
 		if (u_error) {
 			tprintf("= -1 (errno %lu)", u_error);
-			if (syscall_fault_injected(tcp))
-				tprints(" (INJECTED)");
 		} else {
-			tprintf("= %#lx", tcp->u_rval);
+			tprintf("= %#" PRI_klx, tcp->u_rval);
 		}
+		if (syscall_tampered(tcp))
+			tprints(" (INJECTED)");
 	}
 	else if (!(sys_res & RVAL_NONE) && u_error) {
 		switch (u_error) {
@@ -877,7 +909,7 @@ trace_syscall_exiting(struct tcb *tcp)
 					u_error, strerror(u_error));
 			break;
 		}
-		if (syscall_fault_injected(tcp))
+		if (syscall_tampered(tcp))
 			tprintf(" (INJECTED)");
 		if ((sys_res & RVAL_STR) && tcp->auxstr)
 			tprintf(" (%s)", tcp->auxstr);
@@ -888,29 +920,33 @@ trace_syscall_exiting(struct tcb *tcp)
 		else {
 			switch (sys_res & RVAL_MASK) {
 			case RVAL_HEX:
-#if SUPPORTED_PERSONALITIES > 1
-				if (current_wordsize < sizeof(long))
+#if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
+				if (current_wordsize < sizeof(tcp->u_rval)) {
 					tprintf("= %#x",
 						(unsigned int) tcp->u_rval);
-				else
+				} else
 #endif
-					tprintf("= %#lx", tcp->u_rval);
+				{
+					tprintf("= %#" PRI_klx, tcp->u_rval);
+				}
 				break;
 			case RVAL_OCTAL:
 				tprints("= ");
 				print_numeric_long_umask(tcp->u_rval);
 				break;
 			case RVAL_UDECIMAL:
-#if SUPPORTED_PERSONALITIES > 1
-				if (current_wordsize < sizeof(long))
+#if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
+				if (current_wordsize < sizeof(tcp->u_rval)) {
 					tprintf("= %u",
 						(unsigned int) tcp->u_rval);
-				else
+				} else
 #endif
-					tprintf("= %lu", tcp->u_rval);
+				{
+					tprintf("= %" PRI_klu, tcp->u_rval);
+				}
 				break;
 			case RVAL_DECIMAL:
-				tprintf("= %ld", tcp->u_rval);
+				tprintf("= %" PRI_kld, tcp->u_rval);
 				break;
 			case RVAL_FD:
 				if (show_fd_path) {
@@ -918,26 +954,8 @@ trace_syscall_exiting(struct tcb *tcp)
 					printfd(tcp, tcp->u_rval);
 				}
 				else
-					tprintf("= %ld", tcp->u_rval);
+					tprintf("= %" PRI_kld, tcp->u_rval);
 				break;
-#if HAVE_STRUCT_TCB_EXT_ARG
-			/*
-			case RVAL_LHEX:
-				tprintf("= %#llx", tcp->u_lrval);
-				break;
-			case RVAL_LOCTAL:
-				tprintf("= %#llo", tcp->u_lrval);
-				break;
-			*/
-			case RVAL_LUDECIMAL:
-				tprintf("= %llu", tcp->u_lrval);
-				break;
-			/*
-			case RVAL_LDECIMAL:
-				tprintf("= %lld", tcp->u_lrval);
-				break;
-			*/
-#endif /* HAVE_STRUCT_TCB_EXT_ARG */
 			default:
 				error_msg("invalid rval format");
 				break;
@@ -945,6 +963,8 @@ trace_syscall_exiting(struct tcb *tcp)
 		}
 		if ((sys_res & RVAL_STR) && tcp->auxstr)
 			tprintf(" (%s)", tcp->auxstr);
+		if (syscall_tampered(tcp))
+			tprints(" (INJECTED)");
 	}
 	if (Tflag) {
 		tv_sub(&tv, &tv, &tcp->etime);
@@ -961,17 +981,17 @@ trace_syscall_exiting(struct tcb *tcp)
 #endif
 
  ret:
-	tcp->flags &= ~(TCB_INSYSCALL | TCB_FAULT_INJ);
+	tcp->flags &= ~(TCB_INSYSCALL | TCB_TAMPERED);
 	tcp->sys_func_rval = 0;
 	free_tcb_priv_data(tcp);
 	return 0;
 }
 
 int
-trace_syscall(struct tcb *tcp)
+trace_syscall(struct tcb *tcp, unsigned int *signo)
 {
 	return exiting(tcp) ?
-		trace_syscall_exiting(tcp) : trace_syscall_entering(tcp);
+		trace_syscall_exiting(tcp) : trace_syscall_entering(tcp, signo);
 }
 
 bool
@@ -1003,8 +1023,6 @@ restore_cleared_syserror(struct tcb *tcp)
 	tcp->u_error = saved_u_error;
 }
 
-#include "kernel_types.h"
-
 /*
  * Check the syscall return value register value for whether it is
  * a negated errno code indicating an error, or a success return value.
@@ -1015,22 +1033,12 @@ is_negated_errno(kernel_ulong_t val)
 	/* Linux kernel defines MAX_ERRNO to 4095. */
 	kernel_ulong_t max = -(kernel_long_t) 4095;
 
-#if defined X86_64 || defined X32
-	/*
-	 * current_wordsize is 4 for x32 personality
-	 * but truncation _must not_ be done in it, so
-	 * check current_personality instead.
-	 */
-	if (current_personality == 1) {
+#ifndef current_klongsize
+	if (current_klongsize < sizeof(val)) {
 		val = (uint32_t) val;
 		max = (uint32_t) max;
 	}
-#elif SUPPORTED_PERSONALITIES > 1 && SIZEOF_LONG > 4
-	if (current_wordsize < sizeof(val)) {
-		val = (uint32_t) val;
-		max = (uint32_t) max;
-	}
-#endif
+#endif /* !current_klongsize */
 
 	return val >= max;
 }
@@ -1047,7 +1055,7 @@ print_pc(struct tcb *tcp)
 #if defined ARCH_PC_REG
 # define ARCH_GET_PC 0
 #elif defined ARCH_PC_PEEK_ADDR
-	long pc;
+	kernel_ulong_t pc;
 # define ARCH_PC_REG pc
 # define ARCH_GET_PC upeek(tcp->pid, ARCH_PC_PEEK_ADDR, &pc)
 #else
@@ -1057,8 +1065,9 @@ print_pc(struct tcb *tcp)
 		tprints(current_wordsize == 4 ? "[????????] "
 					      : "[????????????????] ");
 	else
-		tprintf(current_wordsize == 4 ? "[%08lx] " : "[%016lx] ",
-			(unsigned long) ARCH_PC_REG);
+		tprintf(current_wordsize == 4
+			? "[%08" PRI_klx "] " : "[%016" PRI_klx "] ",
+			(kernel_ulong_t) ARCH_PC_REG);
 }
 
 #include "getregs_old.h"
@@ -1188,7 +1197,7 @@ set_regs(pid_t pid)
 struct sysent_buf {
 	struct tcb *tcp;
 	struct_sysent ent;
-	char buf[sizeof("syscall_%lu") + sizeof(long) * 3];
+	char buf[sizeof("syscall_%lu") + sizeof(kernel_ulong_t) * 3];
 };
 
 static void
@@ -1216,7 +1225,7 @@ get_scno(struct tcb *tcp)
 	if (rc != 1)
 		return rc;
 
-	if (SCNO_IS_VALID(tcp->scno)) {
+	if (scno_is_valid(tcp->scno)) {
 		tcp->s_ent = &sysent[tcp->scno];
 		tcp->qual_flg = qual_flags(tcp->scno);
 	} else {
@@ -1227,7 +1236,7 @@ get_scno(struct tcb *tcp)
 		s->ent.sen = SEN_printargs;
 		s->ent.sys_func = printargs;
 		s->ent.sys_name = s->buf;
-		sprintf(s->buf, "syscall_%lu", shuffle_scno(tcp->scno));
+		sprintf(s->buf, "syscall_%" PRI_klu, shuffle_scno(tcp->scno));
 
 		tcp->s_ent = &s->ent;
 		tcp->qual_flg = QUAL_RAW | DEFAULT_QUAL_FLAGS;
@@ -1235,7 +1244,8 @@ get_scno(struct tcb *tcp)
 		set_tcb_priv_data(tcp, s, free_sysent_buf);
 
 		if (debug_flag)
-			error_msg("pid %d invalid syscall %ld", tcp->pid, tcp->scno);
+			error_msg("pid %d invalid syscall %" PRI_kld,
+				  tcp->pid, tcp->scno);
 	}
 	return 1;
 }
@@ -1275,11 +1285,11 @@ get_syscall_result(struct tcb *tcp)
 #endif
 
 const char *
-syscall_name(long scno)
+syscall_name(kernel_ulong_t scno)
 {
 #if defined X32_PERSONALITY_NUMBER && defined __X32_SYSCALL_BIT
 	if (current_personality == X32_PERSONALITY_NUMBER)
 		scno &= ~__X32_SYSCALL_BIT;
 #endif
-	return SCNO_IS_VALID(scno) ? sysent[scno].sys_name: NULL;
+	return scno_is_valid(scno) ? sysent[scno].sys_name: NULL;
 }
