@@ -33,6 +33,7 @@
 # endif
 
 # include <sys/types.h>
+# include "kernel_types.h"
 # include "gcc_compat.h"
 
 /* Tests of "strace -v" are expected to define VERBOSE to 1. */
@@ -72,10 +73,10 @@ void *tail_memdup(const void *, const size_t)
  * values starting with start and resetting every period) in order to catch
  * sign, byte order and/or alignment errors.
  */
-void fill_memory_ex(char *ptr, size_t size, unsigned char start,
+void fill_memory_ex(void *ptr, size_t size, unsigned char start,
 		    unsigned char period);
 /* Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
-void fill_memory(char *ptr, size_t size);
+void fill_memory(void *ptr, size_t size);
 
 /* Close stdin, move stdout to a non-standard descriptor, and print. */
 void tprintf(const char *, ...)
@@ -140,6 +141,22 @@ int send_mmsg(int, struct mmsghdr *, unsigned int, unsigned int);
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
 
+#define F8ILL_KULONG_SUPPORTED	(sizeof(void *) < sizeof(kernel_ulong_t))
+#define F8ILL_KULONG_MASK	((kernel_ulong_t) 0xffffffff00000000ULL)
+
+/*
+ * For 64-bit kernel_ulong_t and 32-bit pointer,
+ * return a kernel_ulong_t value by filling higher bits.
+ * For other architertures, return the original pointer.
+ */
+static inline kernel_ulong_t
+f8ill_ptr_to_kulong(const void *const ptr)
+{
+	const unsigned long uptr = (unsigned long) ptr;
+	return F8ILL_KULONG_SUPPORTED
+	       ? F8ILL_KULONG_MASK | uptr : (kernel_ulong_t) uptr;
+}
+
 # define ARRAY_SIZE(arg) ((unsigned int) (sizeof(arg) / sizeof((arg)[0])))
 # define LENGTH_OF(arg) ((unsigned int) sizeof(arg) - 1)
 
