@@ -88,7 +88,8 @@ SYS_FUNC(setuid)
 }
 
 static void
-get_print_uid(struct tcb *tcp, const char *prefix, const long addr)
+get_print_uid(struct tcb *const tcp, const char *const prefix,
+	      const kernel_ulong_t addr)
 {
 	uid_t uid;
 
@@ -164,7 +165,8 @@ print_gid(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 }
 
 static void
-print_groups(struct tcb *tcp, const unsigned int len, const unsigned long addr)
+print_groups(struct tcb *const tcp, const unsigned int len,
+	     const kernel_ulong_t addr)
 {
 	static unsigned long ngroups_max;
 	if (!ngroups_max)
